@@ -1,7 +1,7 @@
 package Mail::Miner::Config;
 
 our ($db, $username, $password) = 
-    ("mm2", "simon", "");
+    ("", "", "");
 
 1;
 
